@@ -5,6 +5,60 @@
 from ssht00ls.classes.config import * 
 import os, sys, requests, ast, json, pathlib, glob, string, getpass, django
 
+# check / start the ssh agent.
+def ssh_agent():
+	"""
+	SSH_AUTH_SOCK = os.environ.get("SSH_AUTH_SOCK")
+	SSH_AGENT_PID = os.environ.get("SSH_AGENT_PID")
+	"""
+	"""
+	try:
+		output = utils.__execute__([f"ssh-add", "-D"])
+	except: a=1
+	try:
+		output = utils.__execute__([f"ssh-add", "-k"])
+	except: a=1
+	"""
+
+	# version 2.
+	try:
+		output = utils.__execute__(f"ssh-agent")
+		try: 
+			SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
+			os.environ["SSH_AUTH_SOCK"] = SSH_AUTH_SOCK
+		except: return None
+		try: 
+			SSH_AGENT_PID = output.split("SSH_AGENT_PID=")[1].split(";")[0]
+			os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
+		except: return None
+	except: return None
+	os.environ["SSH_AUTH_SOCK"] = SSH_AUTH_SOCK
+	os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
+
+# kill all ssh procs with that includes the identifier.
+def kill_ssh(identifier=None, sudo=False, dont_kill=["grep", "ssht00ls"]):
+	response = r3sponse.check_parameters({
+		"identifier:str":identifier,})
+	if not response.success: return response
+	killed = 0
+	output = syst3m.utils.__execute_script__(f"""ps -ax | grep "{identifier}" | """ + """awk '{print $1"|"$2"|"$3"|"$4}' """)
+	for line in output.split("\n"):
+		if line not in ["", " "]:
+			pid,tty,_,process = line.split("|")
+			if process not in dont_kill:
+				loader = syst3m.console.Loader(f"Killing process {pid}.")
+				if sudo: _sudo_ = "sudo "
+				else: _sudo_ = ""
+				output = syst3m.utils.__execute_script__(f"{_sudo_}kill {pid}")
+				if "terminated" in output:
+					loader.stop()
+					killed += 1
+				else:
+					loader.stop(success=False)
+					r3sponse.log(f"Failed to stop process {pid}, error: {output}")
+	return r3sponse.success_response(f"Successfully killed {killed} process(es) that included identifier [{identifier}].")
+
+
 # init a default response.
 def __default_response__():
 	return {
